@@ -1,10 +1,9 @@
 import torch
-import torch.nn as nn
-from torch.utils.data import DataLoader, Dataset
-from transformers import AutoModelForCausalLM, AutoTokenizer, AutoModelForMaskedLM
 from peft import TaskType
-from slimformers import Pruner
-from slimformers import lora_finetune
+from torch.utils.data import DataLoader, Dataset
+from transformers import AutoModelForCausalLM, AutoTokenizer
+
+from slimformers import Pruner, lora_finetune
 
 # Load model and tokenizer
 # model_id = "deepseek-ai/deepseek-coder-1.3b-base"
@@ -21,25 +20,31 @@ texts = [
     "The quick brown fox jumps over the lazy dog.",
     "Artificial intelligence is transforming the world.",
     "LoRA and pruning improve model efficiency.",
-    "Transformers are powerful neural networks."
+    "Transformers are powerful neural networks.",
 ]
 
 encodings = tokenizer(texts, padding=True, truncation=True, return_tensors="pt")
 
+
 # Wrap tokenized data in a Dataset for DataLoader
 class TextDataset(Dataset):
     def __init__(self, encodings):
         self.encodings = encodings
+
     def __len__(self):
         return self.encodings["input_ids"].size(0)
+
     def __getitem__(self, idx):
         return {k: v[idx] for k, v in self.encodings.items()}
 
+
 dataloader = DataLoader(TextDataset(encodings), batch_size=2, shuffle=False)
 
+
 def count_parameters(model):
     return sum(p.numel() for p in model.parameters())
 
+
 # Prune
 pruner = Pruner(model)
 """pruner.prune(
@@ -51,21 +56,24 @@ pruner = Pruner(model)
 pruner.prune(
     dataloader=dataloader,
     strategy=[
-        ("lora_then_prune", {
-            "lora_kwargs": {
-                "epochs": 1,
-                "lr": 1e-4,
-                "r": 16,
-                "alpha": 16,
-                "dropout": 0.05,
-                "optimizer": "adamw"
+        (
+            "lora_then_prune",
+            {
+                "lora_kwargs": {
+                    "epochs": 1,
+                    "lr": 1e-4,
+                    "r": 16,
+                    "alpha": 16,
+                    "dropout": 0.05,
+                    "optimizer": "adamw",
+                },
+                "prune_after": ["ffn", "attention"],
+                "sparsity": 0.4,
+                "max_batches": 5,
             },
-            "prune_after": ["ffn", "attention"], 
-            "sparsity": 0.4,                      
-            "max_batches": 5
-        })
+        )
     ],
-    sparsity=0.3 
+    sparsity=0.3,
 )
 
 print("After pruning:")
@@ -86,9 +94,11 @@ gen_ids = model.generate(
     top_p=0.95,
 )
 
-print("Generated (pruned) text:\n", tokenizer.decode(gen_ids[0], skip_special_tokens=True))
+print(
+    "Generated (pruned) text:\n", tokenizer.decode(gen_ids[0], skip_special_tokens=True)
+)
 
-# Apply LoRA 
+# Apply LoRA
 model = lora_finetune(
     model=model,
     dataloader=dataloader,
@@ -99,8 +109,8 @@ model = lora_finetune(
     alpha=16,
     dropout=0.05,
     task_type=TaskType.CAUSAL_LM,
-    optimizer="sgd",  
-    optimizer_kwargs={"momentum": 0.9}
+    optimizer="sgd",
+    optimizer_kwargs={"momentum": 0.9},
 )
 
 print(f"Fine-tuned model size: {count_parameters(model):,} params")
@@ -117,7 +127,10 @@ gen_ids_ft = model.generate(
     top_k=50,
     top_p=0.95,
 )
-print("Generated (LoRA-finetuned) text:\n", tokenizer.decode(gen_ids_ft[0], skip_special_tokens=True))
+print(
+    "Generated (LoRA-finetuned) text:\n",
+    tokenizer.decode(gen_ids_ft[0], skip_special_tokens=True),
+)
 
 # Stats
-pruner.report()
\ No newline at end of file
+pruner.report()
